@@ -289,9 +289,9 @@ class UniProtReader(object):
                         continue
                     if node2.tagName == "position":
                         position = node2.attributes["position"].value
-                    elif node2.tagName == "begin":
+                    elif node2.tagName == "begin" and "position" in node2.attributes:
                         begin = node2.attributes["position"].value
-                    elif node2.tagName == "end":
+                    elif node2.tagName == "end" and "position" in node2.attributes:
                         end = node2.attributes["position"].value
 
         if position:
